@@ -87,7 +87,7 @@ def run_simulation(num_of_particles,theta_rad,spread,lattice_shape='sqaure'):
 
     #print experiment summary init conds
     print('Initial Conditions')
-    print(' - {} particles spread across {} (x units) at a angle of {} degrees\n'.format(num_of_particles,spread,theta))
+    print(' - {} particles spread across {} (x units) at a angle of {} degrees\n'.format(num_of_particles,spread,theta_rad))
 
     plt.figure('Xray-Diffraction',figsize=(5,5))
     plt.clf()
